@@ -10,19 +10,17 @@ test_that("split_along_dim", {
 
 
 test_that("split_on_dim", {
-
   x <- array(1:840, 4:7)
 
   for (d in seq_along(dim(x))) {
     f <- rep_len(1:2, dim(x)[d])
-    expect_length( split_on_dim(x, d, f), 2L)
+    expect_length(split_on_dim(x, d, f), 2L)
   }
 
 })
 
 
 test_that("split* works recursively", {
-
   x1 <- 1:4
   x2 <- matrix(1:20, nrow = 4, ncol = 5)
   x3 <- array(1:840, 4:7)
@@ -36,7 +34,6 @@ test_that("split* works recursively", {
 })
 
 test_that("split_on f inputs", {
-
   x <- array(1:840, 4:7)
 
   # test a scalar integer
@@ -59,3 +56,19 @@ test_that("split_on f inputs", {
   expect_equal(nrow(l[[3]]), 6L)
 
 })
+
+
+
+test_that("split_along_rows works with common vector types", {
+  m <-  matrix(1:20, nrow = 4, ncol = 5)
+
+  set.seed(42)
+  for (mode in c("integer", "double", "complex", "logical", "list", "character")) {
+    storage.mode(m) <- mode
+    if(mode == "logical")
+      m[] <- sample(c(TRUE, FALSE), length(m), TRUE)
+    identical(split_along_rows(m),
+              lapply(1:4, function(r) m[r, ]))
+  }
+
+})
